#[non_exhaustive]pub enum StorageError {
Sqlite(Error),
Open {
path: PathBuf,
source: Error,
},
Migration {
version: i64,
source: Error,
},
Resolve(ResolveError),
NotFound(String),
MissingBlob(String),
StillRecording(String),
WriterClosed,
WriterPanic,
}Expand description
Storage-layer error.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Sqlite(Error)
SQLite returned an error.
Open
The database file could not be opened or created.
Migration
A migration could not be applied.
Resolve(ResolveError)
A session id did not resolve to exactly one session.
NotFound(String)
A session id was not found.
MissingBlob(String)
A blob referenced by an event does not exist on disk.
StillRecording(String)
redact_session was asked to rewrite a session that is still being
recorded (a live writer could re-insert plaintext mid-rewrite).
WriterClosed
The single-writer task is no longer reachable (closed or panicked).
WriterPanic
The single-writer task panicked while handling a request.